﻿CREATE TABLE movie(
  movie_id        INT NOT NULL,
  title           VARCHAR(200) NOT NULL,
  release_date    DATE NOT NULL,
  plot            VARCHAR(2000),

  CONSTRAINT movie_pk PRIMARY KEY (movie_id)
);

CREATE TABLE imdb_user(
  user_id        INT NOT NULL,
  user_password  INT NOT NULL,
  email          VARCHAR(200) NOT NULL,
  sex            CHAR(1) NOT NULL,
  dob            DATE NOT NULL,
  postal_code    VARCHAR(6) NOT NULL,
  country        VARCHAR(100) NOT NULL,

  CONSTRAINT imdb_user_pk PRIMARY KEY (user_id)
);

CREATE TABLE comment_movie(
  user_id        INT NOT NULL,
  movie_id       INT NOT NULL,
  movie_comment  VARCHAR(2000),

  CONSTRAINT comment_movie_pk PRIMARY KEY (user_id, movie_id),
  CONSTRAINT comment_movie_fk1 FOREIGN KEY (user_id)
             REFERENCES imdb_user(user_id),
  CONSTRAINT comment_movie_fk2 FOREIGN KEY (movie_id)
             REFERENCES movie(movie_id)
);

CREATE TABLE rating_movie(
  user_id        INT NOT NULL,
  movie_id       INT NOT NULL,
  movie_rating   INT,

  CONSTRAINT rating_movie_pk PRIMARY KEY (user_id, movie_id),
  CONSTRAINT rating_movie_fk1 FOREIGN KEY (user_id)
             REFERENCES imdb_user(user_id),
  CONSTRAINT rating_movie_fk2 FOREIGN KEY (movie_id)
             REFERENCES movie(movie_id)
);

CREATE TABLE genre(
  genre_id       INT NOT NULL,
  genre_name     VARCHAR(200),
  description    VARCHAR(200) NOT NULL,

  CONSTRAINT genre_pk PRIMARY KEY (genre_id)
);

CREATE TABLE movie_genre(
  movie_id       INT NOT NULL,
  genre_id       INT NOT NULL,
  genre_name     VARCHAR(200),

  CONSTRAINT movie_genre_pk PRIMARY KEY (genre_id, movie_id),
  CONSTRAINT movie_genre_fk1 FOREIGN KEY (movie_id)
             REFERENCES movie(movie_id),
  CONSTRAINT movie_genre_fk2 FOREIGN KEY (genre_id)
             REFERENCES genre(genre_id)
);

CREATE TABLE tagline(
  movie_id       INT NOT NULL,
  tagline        VARCHAR(200) NOT NULL,

  CONSTRAINT tagline_pk PRIMARY KEY (tagline, movie_id),
  CONSTRAINT tagline_fk FOREIGN KEY (movie_id)
             REFERENCES movie(movie_id)
);

CREATE TABLE keyword(
  movie_id       INT NOT NULL,
  keyword        VARCHAR(200) NOT NULL,

  CONSTRAINT keyword_pk PRIMARY KEY (keyword, movie_id),
  CONSTRAINT keyword_fk FOREIGN KEY (movie_id)
             REFERENCES movie(movie_id)
);

CREATE TABLE cinema(
  cinema_id        INT NOT NULL,
  name             VARCHAR(200) NOT NULL,
  address          VARCHAR(200) NOT NULL,
  postal_code      INT NOT NULL,
  contact_number   INT,

  CONSTRAINT cinema_pk PRIMARY KEY (cinema_id)
);

CREATE TABLE show_movie(
  show_time             INT,
  movie_id              INT NOT NULL,
  cinema_id             INT NOT NULL,
  postal_code           VARCHAR(6) NOT NULL,
  ticket_availability   INT,

  CONSTRAINT show_movie_pk PRIMARY KEY (show_time, movie_id, cinema_id),
  CONSTRAINT show_movie_fk1 FOREIGN KEY (movie_id)
             REFERENCES movie(movie_id),
  CONSTRAINT show_movie_fk2 FOREIGN KEY (cinema_id)
             REFERENCES cinema(cinema_id)
);

CREATE TABLE artist(
  artist_id      INT NOT NULL,
  artist_name    VARCHAR(200) NOT NULL,
  dob            DATE NOT NULL,
  birthplace     VARCHAR(200),
  biography      VARCHAR(2000),

  CONSTRAINT artist_pk PRIMARY KEY (artist_id)
);

CREATE TABLE relationship(
  artist_id               INT NOT NULL,
  spouse_id               INT NOT NULL,
  start_date              DATE NOT NULL,
  end_date                DATE,
  no_of_biological_child  INT,
  no_of_adopted_child     INT,

  CONSTRAINT relationship_pk PRIMARY KEY (start_date, artist_id, spouse_id),
  CONSTRAINT relationship_fk1 FOREIGN KEY (artist_id)
             REFERENCES artist(artist_id),
  CONSTRAINT relationship_fk2 FOREIGN KEY (spouse_id)
             REFERENCES artist(artist_id)
);

CREATE TABLE photo(
  photo_id          INT NOT NULL,
  photo_location    VARCHAR(200) NOT NULL,
  movie_id          INT,

  CONSTRAINT photo_pk PRIMARY KEY (photo_id),
  CONSTRAINT photo_fk FOREIGN KEY (movie_id)
             REFERENCES movie(movie_id)
);

CREATE TABLE artist_photo(
  photo_id    INT NOT NULL,
  artist_id   INT NOT NULL,

  CONSTRAINT artist_photo_pk PRIMARY KEY (photo_id, artist_id),
  CONSTRAINT artist_photo_fk1 FOREIGN KEY (photo_id)
             REFERENCES photo(photo_id),
  CONSTRAINT artist_photo_fk2 FOREIGN KEY (artist_id)
             REFERENCES artist(artist_id)
);

CREATE TABLE write_movie(
  movie_id    INT NOT NULL,
  artist_id   INT NOT NULL,

  CONSTRAINT write_movie_pk PRIMARY KEY (movie_id, artist_id),
  CONSTRAINT write_movie_fk1 FOREIGN KEY (movie_id)
             REFERENCES movie(movie_id),
  CONSTRAINT write_movie_fk2 FOREIGN KEY (artist_id)
             REFERENCES artist(artist_id)
);

CREATE TABLE direct_movie(
  movie_id    INT NOT NULL,
  artist_id   INT NOT NULL,

  CONSTRAINT direct_movie_pk PRIMARY KEY (movie_id, artist_id),
  CONSTRAINT direct_movie_fk1 FOREIGN KEY (movie_id)
             REFERENCES movie(movie_id),
  CONSTRAINT direct_movie_fk2 FOREIGN KEY (artist_id)
             REFERENCES artist(artist_id)
);

CREATE TABLE cast_movie(
  movie_id    INT NOT NULL,
  artist_id   INT NOT NULL,
  role        VARCHAR(200) NOT NULL,

  CONSTRAINT cast_movie_pk PRIMARY KEY (role,movie_id, artist_id),
  CONSTRAINT cast_movie_fk1 FOREIGN KEY (movie_id)
             REFERENCES movie(movie_id),
  CONSTRAINT cast_movie_fk2 FOREIGN KEY (artist_id)
             REFERENCES artist(artist_id)
);

CREATE TABLE award_association(
  association_id  INT NOT NULL,
  name            VARCHAR(200),
  address         VARCHAR(200),
  website         VARCHAR(200),

  CONSTRAINT award_association_pk PRIMARY KEY (association_id)
);

CREATE TABLE award_type(
  association_id   INT NOT NULL,
  type_name        VARCHAR(200) NOT NULL,
  award_format     VARCHAR(200),

  CONSTRAINT award_type_pk PRIMARY KEY (type_name, association_id),
  CONSTRAINT award_type_fk FOREIGN KEY (association_id)
             REFERENCES award_association(association_id)
);

CREATE TABLE award_category(
  association_id   INT NOT NULL,
  type_name        VARCHAR(200) NOT NULL,
  category_name    VARCHAR(200) NOT NULL,

  CONSTRAINT award_category_pk PRIMARY KEY (category_name, association_id, type_name),
  CONSTRAINT award_category_fk2 FOREIGN KEY (association_id, type_name)
             REFERENCES award_type(association_id, type_name)
);

CREATE TABLE movie_award(
  association_id     INT NOT NULL,
  type_name          VARCHAR(200) NOT NULL,
  category_name      VARCHAR(200) NOT NULL,
  movie_award_year   INT NOT NULL,
  movie_id           INT NOT NULL,
  winner             CHAR(1) NOT NULL,

  CONSTRAINT movie_award_pk PRIMARY KEY (movie_id, category_name, association_id, type_name),
  CONSTRAINT movie_award_fk1 FOREIGN KEY (association_id)
             REFERENCES award_association(association_id),
  CONSTRAINT movie_award_fk2 FOREIGN KEY (type_name)
             REFERENCES award_type(type_name),
  CONSTRAINT movie_award_fk4 FOREIGN KEY (movie_id)
             REFERENCES movie(movie_id),
  CONSTRAINT movie_award_fk3 FOREIGN KEY (category_name)
             REFERENCES award_category(category_name)

);


CREATE TABLE artist_award(
  association_id     INT NOT NULL,
  type_name          VARCHAR(200) NOT NULL,
  category_name      VARCHAR(200) NOT NULL,
  artist_award_year  INT NOT NULL,
  movie_id           INT NOT NULL,
  artist_id          INT NOT NULL,
  winner             CHAR(1) NOT NULL,

  CONSTRAINT artist_award_pk PRIMARY KEY (artist_id, movie_id, category_name, association_id, type_name),
  CONSTRAINT artist_award_fk1 FOREIGN KEY (association_id)
             REFERENCES award_association(association_id),
  CONSTRAINT artist_award_fk2 FOREIGN KEY (type_name)
             REFERENCES award_type(type_name),
  CONSTRAINT artist_award_fk3 FOREIGN KEY (category_name)
             REFERENCES award_category(category_name),
  CONSTRAINT artist_award_fk4 FOREIGN KEY (movie_id)
             REFERENCES movie(movie_id),
  CONSTRAINT artist_award_fk5 FOREIGN KEY (artist_id)
             REFERENCES artist(artist_id)
);